@@ -73,7 +73,7 @@ vert_GET <- function(fxn="searchbyterm", args, limit = 1000, messages = TRUE,
     res <- get_terms()
     df <- df[ , names(df) %in% res ]
   }
-  mssg(messages, paste("\nLast Query URL: \"", tt$url, "\"", sep = ""))
+  mssg(messages, paste("\nLast Query URL: \"", URLdecode(tt$url), "\"", sep = ""))
   mssg(messages, paste("\nMatching records:", NROW(df), "returned,", avail, "available", sep = " "))
   list(meta = make_meta(out), data = tbl_df(df))
 }
@@ -174,7 +174,7 @@ rvc <- function(x) Filter(Negate(is.null), x)
 
 assert <- function(x, y) {
   if (!is.null(x)) {
-    if (!class(x) %in% y) {
+    if (!inherits(x, y)) {
       stop(deparse(substitute(x)), " must be of class ",
            paste0(y, collapse = ", "), call. = FALSE)
     }
